import { LitElement } from 'lit';
/**
 *  @element uui-slider
 *  @description - Native `<input type="range">` wrapper.
 *  @fires UUISliderEvent#input on input
 *
 */
export declare class UUISliderElement extends LitElement {
    static styles: import("lit").CSSResult[];
    /**
     * This is a static class field indicating that the element is can be used inside a native form and participate in its events. It may require a polyfill, check support here https://developer.mozilla.org/en-US/docs/Web/API/HTMLElement/attachInternals.  Read more about form controls here https://web.dev/more-capable-form-controls/
     * @type {boolean}
     */
    static readonly formAssociated = true;
    private _input;
    private _track;
    /**
     * Hides the numbers representing the value of each steps. Dots will still be visible
     * @type {boolean}
     * @attr 'hide-step-values'
     * @default false
     */
    hideStepValues: boolean;
    /**
     * This is a minimum value of the input.
     * @type {number}
     * @attr
     * @default 100
     */
    min: number;
    /**
     * This is a maximum value of the input.
     * @type {number}
     * @attr
     * @default 100
     */
    max: number;
    /**
     * This reflects the behavior of a native input step attribute.
     * @type {number}
     * @attr
     * @default 1
     */
    step: number;
    private _value;
    /**
     * This is a value property of the uui-slider.
     * @type {string}
     * @attr
     * @default ''
     */
    get value(): string;
    set value(newVal: string);
    /**
     * Disables interaction.
     * @type {boolean}
     * @attr
     * @default false
     */
    disabled: boolean;
    /**
     * Label to be used for aria-label and eventually as visual label
     * @type {string}
     * @attr
     */
    label: string;
    private _internals;
    constructor();
    /**
     * This method enables <label for="..."> to focus the input
     */
    focus(): void;
    connectedCallback(): void;
    disconnectedCallback(): void;
    firstUpdated(): void;
    updated(changedProperties: any): void;
    private _updateSteps;
    private stepWidth;
    private _calculateStepWidth;
    private onWindowResize;
    protected steps: number[];
    protected sliderPosition: string;
    private _calculateSliderPosition;
    private _onInput;
    private _onChange;
    render(): import("lit-html").TemplateResult<1>;
}
